@@ -9,6 +9,8 @@ from django.contrib.contenttypes.models import ContentType
 from django.db.models.signals import post_delete
 from django.dispatch import receiver
 
+from taggit.managers import TaggableManager
+
 
 class Risk(NetBoxModel):
     name = models.CharField(
@@ -82,9 +84,7 @@ class Risk(NetBoxModel):
     )
     comments = models.TextField(blank=True)
 
-    tags = models.ForeignKey(
-        to=ContentType,
-        on_delete=models.CASCADE,
+    tags = TaggableManager(
         related_name='risk_tags'
     )
 
@@ -131,6 +131,9 @@ class RiskRelation(NetBoxModel):
         blank=True,
     )
 
+    tags = TaggableManager(
+        related_name='riskrelations_tags'
+    )
 
     class Meta:
         ordering = ['name']
